# Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog, and this project adheres to Semantic Versioning.

## [0.1.2] - 2023-05-09

### Added

- `readme.md` in package via manifest.in
- `license` in package via manifest.in
- `changelog.md` in package via manifest.in

### Changed

 - Update `readme.md` with supported languages

### Fixed

 - Syntax error in `readme.md` config example

## [0.1.1] - 2023-05-09

### Added

- Support for Python (.py) code files
- `readme.md` as long description in setup

## [0.1.0] - 2023-05-09

### Added

- `plugin.py`
- Support for PDF, CSharp (.cs), CSS (.css), Dart (.dart), HTML (.html), Javascript (.js), JSON (.json), PHP (.php) code files